# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['nexus_api']

package_data = \
{'': ['*']}

install_requires = \
['pandas']

setup_kwargs = {
    'name': 'nexus-integra-api',
    'version': '0.6.0',
    'description': ' Nexus API connection methods and utilities',
    'long_description': '# nexus_integra_api\nEste repositorio tiene como propósito reunir en una única libería todas las funciones necesarias para trabajar con la API de Nexus en Python.\nEn lugar de importar los archivos a la carpeta del proyecto cada vez que se usan puede instalarse la librería en la PATH de Python \n\n## Table of Contents\n\n* [Instalación](#chapter1)\n* [Uso](#chapter2)\n* [Ejemplos](#chapter3)\n  * [GetFiltered](#chapter3.1)\n  * [Uso de alarmas](#chapter3.2)\n  * [Email Alerts](#chapter3.3)\n* [Contribuir](#chapter4)\n* [Change Log](#chapter5)\n* [Contacto](#chapter6)\n\n## Instalación <a class="anchor" id="chapter1"></a>\n\nUsa el package manager pip para instalar la librería. Puede instalarse de forma local o desde el repositorio de PyPi\n\n```\npip install nexus_integra_api\n```\n\n## Uso <a class="anchor" id="chapter2"></a>\nPara importar todo el contenido de la librería, una vez instalada hay que realizar el siguiente import:\n\n    import nexus_api\nSi únicamente se desea la clase en la que residen las funciones que trabajan con la API:\n\n    from nexus_api import APINexus\nLo que otorga acceso a la clase APINexus en la que residen todas las funciones necesarias.\n\n## Ejemplo de uso <a class="anchor" id="chapter3"></a>\n\n### GetFiltered <a class="anchor" id="chapter3.1"></a>\nUn ejemplo de uso para la famosa función GetFiltered que permite filtrar el histórico de variables entre un periodo dado:\n\nEn primer lugar se especifican los parámetros de conexión y se crea el objeto Nexus, además de los imports necesarios\n```\nfrom nexus_api import APINexus\nimport pandas as pd\nimport datetime\n\nAPI_Host = \'nexus-cdi-demo.globalomnium.com\'  \nAPI_Port = 56000 \nNexusToken = \'xxxxxxxxxxxxxxxxx\' \nversion = \'v1\'\nNX = APINexus.APINexus(API_Host, API_Port, NexusToken, version)\n```\nDespués es necesario obtener el uid de la vista de variables que se quiere leer (también existe función para leer desde instalación)\n```\n# Leer vistas de variables asociadas al token  \ntagviews = NX.callGetDocuments()  \ntagviews = json_normalize(tagviews)  \n# Busqueda del uid de la vista\nuid_tagview = tagviews.uid[0]\n```\nSe especifica la ventana temporal deseada:\n```\n# Profundidad del análisis en fechas desde hoy  \ndelta_days = xxx  \ndate_format = \'%m/%d/%Y %H:%M:%S %Z\'  \ndate_to = datetime.datetime.now()  \ndate_from = date_to - datetime.timedelta(days=delta_days)\n```\nHay que especificar las variables deseadas de la vista de variables elegida. Con este código se obtienen todos los uids de las variables de la vista. Es necesario filtrar \n```\n# Variables en la vista de variables  \nvbles = NX.callGetTagViews(uid_tagview)  \ndf = pd.DataFrame(vbles)  \ncolumnas = df[\'columns\']  \ncolumnas = json_normalize(columnas)  \nuids_vbles = list(columnas[\'uid\'])  # String with variables UIDS\n```\nFinalmente se obtiene el histórico llamando a la función:\n```\nfiltered_hist = NX.filter_tagview(date_from, date_to, columnas, uid_tagview, \'variable\')\n```\n\n### Uso de alarmas <a class="anchor" id="chapter3.2"></a>\nDesde la versión **0.4** del encapsulado pueden modificarse alarmas en la API. Para ello se debe obtener el uid de la alarma a modificar y luego llamar a la función:\n#### Obtener uids de alarmas del token\n```\nalarmas = NX.callGetAlarms()\n```\n\n#### Obtener información de alarma por uid\n```\nalarma = NX.callGetAlarmByuid(uid)\n```\n\n#### Obtener uids de alarmas por nombres. Puede usarse una lista de nombres o un string con un nombre\n```\nuids_alarmas = NX.get_alarms_uids_by_names([names])\n```\n#### Obtener uids de alarmas por grupos de alarmas. Puede usarse una lista de grupos o un string con un grupo\n```\nuids_grupo = NX.get_alarms_uids_by_groups([groups])\n```\n\n#### Cambiar el estado de la alarma. Debe especificarse el uid de la alarma y el estado a cambiar (\'ARE\' o \'EXR\')\n```\nNX.callPostAckAlarm(uid, estado)\n```\n\n#### Cambiar el mensaje de estado de la alarma\n```\nNX.callPostAlarmEvent(uid, msg)\n```\n\n### Email Alerts <a class="anchor" id="chapter3.3"></a>\nDesde la versión **0.5** se añade soporte para generar alarmas de correo eléctronico.\n\nPara usar la función debe crearse un objeto de tipo EmailAlerts. Deben proporcionarse los parámetros de conexión.\n\nSe recomienda usar variables de entorno para proteger las credenciales. En caso de no estar definidas se deben especificar (reemplazar las líneas de os.getenv()):\n\n```\nimport os\n\nsmtp_address = \'outlook.office365.com\'\nsmtp_port = 587\n\n# datos de la cuenta de envio\nsender_email_address = os.getenv("SENDER_EMAIL_ADDRESS")\nemail_password = os.getenv("EMAIL_PASSWORD")\nreceiver_email_address = os.getenv("RECEIVER_EMAIL_ADDRESS")\n\nemail_alerts = EmailAlerts(smtp_address, smtp_port, sender_email_address, email_password, receiver_email_address)\n```\n\nUna vez creado el objeto email_alerts puede usarse con libertad, bien con los parámetros predeterminados o moficiando los componentes del mensaje\n\nEl asunto y el cuerpo del mensaje tienen valores predeterminados en función del nombre del archivo, pero environment es una variable requerida con la que identificar el entorno de producción.\n```\nenviroment = \'NEXUS_PROD\'\nsubject = \'ALARMA\'\nbody = \'Alarma de \' + environment\n\nemail_alerts.set_email_alert_info(subject, body, environment)\n```\n\n\nSe puede usar la alerta de correo en cualquier función, sea de la API o no. Si la ejecución falla, \nse captura la excepción y se envía un correo con el error (mensaje predeterminado).\n\nSi se quiere incorporar a un script entero, debe usarse la función main()\n\n```\n# Uso del decorador para generar el correo\n\n@email_alerts.email_alert_decorator\ndef main():\n    # Aquí va todo el código del programa...\n    raise Exception(\'Error en la función\')\n    \nif __name__ == \'__main__\':\n    main() # Si aparece un error, se envía un correo con el error\n```\n\n## Contribuir <a class="anchor" id="chapter4"></a>\n\nCualquier función o sugerencia añadida es bien recibida.\n\nSugerencias:\n\n- Falta documentar las funciones de la API\n- Traducir documentación\n\n## Change log <a class="anchor" id="chapter5"></a>\n\n###v0.5.0 - 12/04/2022\n\n**Added**\n\n - Email alerts functions\n\n**Changed**\n\n - Documentation\n\n###v0.4.0 - 30/03/2022\n\n**Added**\n  \n- API V2 alarm functions\n  * callPostAckAlarm(uid, status)\n  * callPostAlarmEvent(uid, msg)\n  * callGetAlarms()\n  * callGetAlarmByuid(uid)\n  * get_alarms_uids_by_names([names])\n  * get_alarms_uids_by_groups([groups])\n- Unit tests\n- .env file in order protect credentials\n- Bypassed 50k row limit in POST methods\n- Added support to datetime objects in callPostValueHist\n  \n**Modified**\n  \n- Unified callPostValueHist and callPostValueHistmult (deprecated)\n  \n###v0.3.2 - 11/03/2022\n**Added**\n- Add filter_installation and filter_tagview as replacement for GetFiltered\n- Add README.md\n\n## Contacto <a class="anchor" id="chapter6"></a>\n[**Pau Juan**](mailto:pau.juan@nexusintegra.io)\n*Operaciones*\n\n\n[**Laura Moreno**](mailto:laura.moreno@nexusintegra.io)\n*Operaciones*\n\n\n[**Ricardo Gómez**](mailto:ricardo.gomez.aldaravi@nexusintegra.io)\n*Operaciones*\n\n[Nexus Integra](https://nexusintegra.io/)',
    'author': 'Nexus Integra',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://nexusintegra.io',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
